@@ -8,12 +8,12 @@
     cunningr - 2020
 
     Requires:
-     - openpyxl >= 2.6.2
+     - openpyxl >= 2.6.2 <= 3.0.3
      - jsonschema
 
 
 """
 
-__version__ = "1.0.0"
+__version__ = "1.0.3"
 
 from sdtables.xlTables import *
