@@ -5,9 +5,9 @@
     xlTables - Load/generate table data with Excel
     from python dictionary structures
 
-    cunningr@cisco.com - 2019
+    cunningr - 2020
 
-    Requires openpyxl >= 2.6.2
+    Requires openpyxl >= 2.6.2, jsonschema
 
 
 """
@@ -302,6 +302,11 @@ def _add_column_data_validation(_work_sheet, headers, _schema, col_offset=0):
             _work_sheet.add_data_validation(_dv)
             _col = _get_cell_column_letter(idx + col_offset)
             dv_dict.update({_col: _dv})
+        elif 'boolean' in _schema['properties'][column]['type']:
+            _dv = _create_bool_dv(allow_blank=True)
+            _work_sheet.add_data_validation(_dv)
+            _col = _get_cell_column_letter(idx + col_offset)
+            dv_dict.update({_col: _dv})
 
     return dv_dict
 
@@ -346,6 +351,7 @@ def _validate_data(_schema, _data):
             validate(instance=_row, schema=_schema)
         except Exception as e:
             has_error = True
+            print('ROW: {}'.format(_row))
             error = 'ERROR:', e
             print(error)
 
@@ -357,6 +363,8 @@ def _validate_data(_schema, _data):
 
 def _create_enum_dv(values, allow_blank=True):
 
+    # Remove 'null' values from JSON schema
+    values = [x for x in values if x is not None]
     # Stringify values and create data-validation object
     _values = '"{}"'.format(','.join(values))
     dv = DataValidation(type="list", formula1=_values, allow_blank=allow_blank)
@@ -380,6 +388,19 @@ def _create_tref_dv(_tref, allow_blank=True):
     return dv
 
 
+def _create_bool_dv(allow_blank=True):
+
+    # Stringify values and create data-validation object
+    _values = '"{}"'.format(','.join(['TRUE', 'FALSE']))
+    dv = DataValidation(type="list", formula1=_values, allow_blank=allow_blank)
+
+    # Optionally set a custom error message
+    dv.error = 'Entry not in the list'
+    dv.errorTitle = 'Invalid Entry'
+
+    return dv
+
+
 def _get_cell_coordinates(cell):
     xy = openpyxl.utils.cell.coordinate_from_string(cell)
     col = openpyxl.utils.cell.column_index_from_string(xy[0])
